Description: Lists all of the available service-specific resources, actions, and condition keys that can be used in IAM policies to control access to AWS Control Tower.

Actions, resources, and condition keys for AWS Control Tower - Service Authorization Reference

# Actions, resources, and condition keys for AWS Control Tower

AWS Control Tower (service prefix: `controltower` ) provides the following service-specific resources, actions, and condition context keys for use in IAM permission policies.

References:

- Learn how to configure this service .

- View a list of the API operations available for this service .

- Learn how to secure this service and its resources by using IAM permission policies.

Topics

- Actions defined by AWS Control Tower
- Resource types defined by AWS Control Tower
- Condition keys for AWS Control Tower

## Actions defined by AWS Control Tower

You can specify the following actions in the `Action` element of an IAM policy statement. Use policies to grant permissions to perform an operation in AWS. When you use an action in a policy, you usually allow or deny access to the API operation or CLI command with the same name. However, in some cases, a single action controls access to more than one operation. Alternatively, some operations require several different actions.

The Resource types column indicates whether each action supports resource-level permissions. If there is no value for this column, you must specify all resources ("*") in the `Resource` element of your policy statement. If the column includes a resource type, then you can specify an ARN of that type in a statement with that action. Required resources are indicated in the table with an asterisk (*). If you specify a resource-level permission ARN in a statement using this action, then it must be of this type. Some actions support multiple resource types. If the resource type is optional (not indicated as required), then you can choose to use one but not the other.

For details about the columns in the following table, see Actions table .

Actions | Description | Access level | Resource types (*required) | Condition keys | Dependent actions
--- | --- | --- | --- | --- | ---
CreateManagedAccount [permission only] | Grants permission to create an account managed by AWS Control Tower. | Write |  |  |
DeregisterManagedAccount [permission only] | Grants permission to deregister an account created through the account factory from AWS Control Tower. | Write |  |  |
DeregisterOrganizationalUnit [permission only] | Grants permission to deregister an organizational unit from AWS Control Tower management. | Write |  |  |
DescribeAccountFactoryConfig [permission only] | Grants permission to describe the current account factory configuration. | Read |  |  |
DescribeCoreService [permission only] | Grants permission to describe resources managed by core accounts in AWS Control Tower. | Read |  |  |
DescribeGuardrail [permission only] | Grants permission to describe a guardrail. | Read |  |  |
DescribeGuardrailForTarget [permission only] | Grants permission to describe a guardrail for a organizational unit. | Read |  |  |
DescribeManagedAccount [permission only] | Grants permission to describe an account created through account factory. | Read |  |  |
DescribeManagedOrganizationalUnit [permission only] | Grants permission to describe an AWS Organizations organizational unit managed by AWS Control Tower. | Read |  |  |
DescribeSingleSignOn [permission only] | Grants permission to describe the current AWS Control Tower SSO configuration. | Read |  |  |
DisableGuardrail [permission only] | Grants permission to disable a guardrail from an organizational unit. | Write |  |  |
EnableGuardrail [permission only] | Grants permission to enable a guardrail to an organizational unit. | Write |  |  |
GetAvailableUpdates [permission only] | Grants permission to list available updates for the current AWS Control Tower deployment. | Read |  |  |
GetGuardrailComplianceStatus [permission only] | Grants permission to get the current compliance status of a guardrail. | Read |  |  |
GetHomeRegion [permission only] | Grants permission to get the home region of the AWS Control Tower setup. | Read |  |  |
GetLandingZoneStatus [permission only] | Grants permission to get the current status of the landing zone setup. | Read |  |  |
ListDirectoryGroups [permission only] | Grants permission to list the current directory groups available through SSO. | List |  |  |
ListEnabledGuardrails [permission only] | Grants permission to list currently enabled guardrails. | List |  |  |
ListGuardrailViolations [permission only] | Grants permission to list existing guardrail violations. | List |  |  |
ListGuardrails [permission only] | Grants permission to list all available guardrails. | List |  |  |
ListGuardrailsForTarget [permission only] | Grants permission to list guardrails and their current state for a organizational unit. | List |  |  |
ListManagedAccounts [permission only] | Grants permission to list accounts managed through AWS Control Tower. | List |  |  |
ListManagedAccountsForGuardrail [permission only] | Grants permission to list managed accounts with a specified guardrail applied. | List |  |  |
ListManagedAccountsForParent [permission only] | Grants permission to list managed accounts under an organizational unit. | List |  |  |
ListManagedOrganizationalUnits [permission only] | Grants permission to list organizational units managed by AWS Control Tower. | List |  |  |
ListManagedOrganizationalUnitsForGuardrail [permission only] | Grants permission to list managed organizational units that have a specified guardrail applied. | List |  |  |
ManageOrganizationalUnit [permission only] | Grants permission to set up an organizational unit to be managed by AWS Control Tower. | Write |  |  |
SetupLandingZone [permission only] | Grants permission to set up or update AWS Control Tower landing zone. | Write |  |  |
UpdateAccountFactoryConfig [permission only] | Grants permission to update the account factory configuration. | Write |  |  |

## Resource types defined by AWS Control Tower

AWS Control Tower does not support specifying a resource ARN in the `Resource` element of an IAM policy statement. To allow access to AWS Control Tower, specify `“Resource”: “*”` in your policy.

## Condition keys for AWS Control Tower

Control Tower has no service-specific context keys that can be used in the `Condition` element of policy statements. For the list of the global context keys that are available to all services, see Available keys for conditions .

Did this page help you? - Yes

Thanks for letting us know we're doing a good job!

If you've got a moment, please tell us what we did right so we can do more of it.

Did this page help you? - No

Thanks for letting us know this page needs work. We're sorry we let you down.

If you've got a moment, please tell us how we can make the documentation better.